@@ -211,6 +211,8 @@ def loadcontext(object_type, uri, name=None, relative_to=None,
         else:
             # @@: Ignore fragment or error?
             uri = uri.split('#', 1)[0]
+    if name is None:
+        name = 'main'
     scheme, path = uri.split(':', 1)
     scheme = scheme.lower()
     if scheme not in _loaders:
@@ -305,6 +307,8 @@ class ConfigLoader(_Loader):
         self.parser.read(filename)
         self.parser._defaults.setdefault(
             'here', os.path.dirname(os.path.abspath(filename)))
+        self.parser._defaults.setdefault(
+            '__file__', os.path.abspath(filename))
 
     def get_context(self, object_type, name=None, global_conf=None):
         if self.absolute_name(name):
